# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from alphausblue.api import account_pb2 as api_dot_account__pb2
from alphausblue.api import operation_pb2 as api_dot_operation__pb2
from alphausblue.cost.v1 import cost_pb2 as cost_dot_v1_dot_cost__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class CostStub(object):
    """Service for reading aggregated costs for your cloud costs and usages.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPayerAccounts = channel.unary_stream(
                '/blueapi.cost.v1.Cost/ListPayerAccounts',
                request_serializer=cost_dot_v1_dot_cost__pb2.ListPayerAccountsRequest.SerializeToString,
                response_deserializer=api_dot_account__pb2.Account.FromString,
                )
        self.GetPayerAccount = channel.unary_unary(
                '/blueapi.cost.v1.Cost/GetPayerAccount',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetPayerAccountRequest.SerializeToString,
                response_deserializer=api_dot_account__pb2.Account.FromString,
                )
        self.GetPayerAccountImportHistory = channel.unary_stream(
                '/blueapi.cost.v1.Cost/GetPayerAccountImportHistory',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetPayerAccountImportHistoryRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.GetPayerAccountImportHistoryResponse.FromString,
                )
        self.CreatePayerAccount = channel.unary_unary(
                '/blueapi.cost.v1.Cost/CreatePayerAccount',
                request_serializer=cost_dot_v1_dot_cost__pb2.CreatePayerAccountRequest.SerializeToString,
                response_deserializer=api_dot_account__pb2.Account.FromString,
                )
        self.DeletePayerAccount = channel.unary_unary(
                '/blueapi.cost.v1.Cost/DeletePayerAccount',
                request_serializer=cost_dot_v1_dot_cost__pb2.DeletePayerAccountRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListAccounts = channel.unary_stream(
                '/blueapi.cost.v1.Cost/ListAccounts',
                request_serializer=cost_dot_v1_dot_cost__pb2.ListAccountsRequest.SerializeToString,
                response_deserializer=api_dot_account__pb2.Account.FromString,
                )
        self.GetAccount = channel.unary_unary(
                '/blueapi.cost.v1.Cost/GetAccount',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetAccountRequest.SerializeToString,
                response_deserializer=api_dot_account__pb2.Account.FromString,
                )
        self.CreateAccount = channel.unary_unary(
                '/blueapi.cost.v1.Cost/CreateAccount',
                request_serializer=cost_dot_v1_dot_cost__pb2.CreateAccountRequest.SerializeToString,
                response_deserializer=api_dot_account__pb2.Account.FromString,
                )
        self.DeleteAccount = channel.unary_unary(
                '/blueapi.cost.v1.Cost/DeleteAccount',
                request_serializer=cost_dot_v1_dot_cost__pb2.DeleteAccountRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetCalculatorStatus = channel.unary_unary(
                '/blueapi.cost.v1.Cost/GetCalculatorStatus',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetCalculatorStatusRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.GetCalculatorStatusResponse.FromString,
                )
        self.GetCalculatorConfig = channel.unary_unary(
                '/blueapi.cost.v1.Cost/GetCalculatorConfig',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetCalculatorConfigRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.GetCalculatorConfigResponse.FromString,
                )
        self.ImportCurFiles = channel.unary_unary(
                '/blueapi.cost.v1.Cost/ImportCurFiles',
                request_serializer=cost_dot_v1_dot_cost__pb2.ImportCurFilesRequest.SerializeToString,
                response_deserializer=api_dot_operation__pb2.Operation.FromString,
                )
        self.CalculateCosts = channel.unary_unary(
                '/blueapi.cost.v1.Cost/CalculateCosts',
                request_serializer=cost_dot_v1_dot_cost__pb2.CalculateCostsRequest.SerializeToString,
                response_deserializer=api_dot_operation__pb2.Operation.FromString,
                )
        self.ListCalculationsHistory = channel.unary_unary(
                '/blueapi.cost.v1.Cost/ListCalculationsHistory',
                request_serializer=cost_dot_v1_dot_cost__pb2.ListCalculationsHistoryRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.ListCalculationsHistoryResponse.FromString,
                )
        self.ReadCosts = channel.unary_stream(
                '/blueapi.cost.v1.Cost/ReadCosts',
                request_serializer=cost_dot_v1_dot_cost__pb2.ReadCostsRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.CostItem.FromString,
                )
        self.ReadAdjustments = channel.unary_stream(
                '/blueapi.cost.v1.Cost/ReadAdjustments',
                request_serializer=cost_dot_v1_dot_cost__pb2.ReadAdjustmentsRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.CostItem.FromString,
                )
        self.ReadTagCosts = channel.unary_stream(
                '/blueapi.cost.v1.Cost/ReadTagCosts',
                request_serializer=cost_dot_v1_dot_cost__pb2.ReadTagCostsRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.CostItem.FromString,
                )
        self.ReadNonTagCosts = channel.unary_stream(
                '/blueapi.cost.v1.Cost/ReadNonTagCosts',
                request_serializer=cost_dot_v1_dot_cost__pb2.ReadNonTagCostsRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.CostItem.FromString,
                )
        self.GetForecasts = channel.unary_unary(
                '/blueapi.cost.v1.Cost/GetForecasts',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetForecastsRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.GetForecastsResponse.FromString,
                )
        self.GetMonthlyCostForecast = channel.unary_unary(
                '/blueapi.cost.v1.Cost/GetMonthlyCostForecast',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetMonthlyCostForecastRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.GetMonthlyCostForecastResponse.FromString,
                )
        self.GetMonthOnMonthCostForecast = channel.unary_unary(
                '/blueapi.cost.v1.Cost/GetMonthOnMonthCostForecast',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetMonthOnMonthCostForecastRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.GetMonthOnMonthCostForecastResponse.FromString,
                )
        self.GetMonthToDateCostForecast = channel.unary_unary(
                '/blueapi.cost.v1.Cost/GetMonthToDateCostForecast',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetMonthToDateCostForecastRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.GetMonthToDateCostForecastResponse.FromString,
                )
        self.GetAccountBudget = channel.unary_unary(
                '/blueapi.cost.v1.Cost/GetAccountBudget',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetAccountBudgetRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.GetAccountBudgetResponse.FromString,
                )
        self.CreateAccountBudget = channel.unary_unary(
                '/blueapi.cost.v1.Cost/CreateAccountBudget',
                request_serializer=cost_dot_v1_dot_cost__pb2.CreateAccountBudgetRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.CreateAccountBudgetResponse.FromString,
                )
        self.UpdateAccountBudget = channel.unary_unary(
                '/blueapi.cost.v1.Cost/UpdateAccountBudget',
                request_serializer=cost_dot_v1_dot_cost__pb2.UpdateAccountBudgetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteAccountBudget = channel.unary_unary(
                '/blueapi.cost.v1.Cost/DeleteAccountBudget',
                request_serializer=cost_dot_v1_dot_cost__pb2.DeleteAccountBudgetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetRecommendations = channel.unary_unary(
                '/blueapi.cost.v1.Cost/GetRecommendations',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetRecommendationsRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.GetRecommendationsResponse.FromString,
                )
        self.GetCostReduction = channel.unary_unary(
                '/blueapi.cost.v1.Cost/GetCostReduction',
                request_serializer=cost_dot_v1_dot_cost__pb2.GetCostReductionRequest.SerializeToString,
                response_deserializer=cost_dot_v1_dot_cost__pb2.GetCostReductionResponse.FromString,
                )


class CostServicer(object):
    """Service for reading aggregated costs for your cloud costs and usages.
    """

    def ListPayerAccounts(self, request, context):
        """Lists vendor payer accounts. For AWS, these are management accounts (formerly known
        as master or payer accounts); for Azure, these are subscriptions, for GCP, these
        are projects.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPayerAccount(self, request, context):
        """Gets a vendor payer account. This API includes all of the account's metadata.
        See https://alphauslabs.github.io/blueapi/ for the list of supported attributes.
        For AWS, this means a management account (formerly known as master or payer account);
        for Azure, this means a subscription, for GCP, this means a project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPayerAccountImportHistory(self, request, context):
        """Gets a payer account's import history, which is a list of timestamps our system tracks when the account's data are
        imported to our system, which in turn, triggers processing. At the moment, this only supports AWS (CUR files).
        You can also set {id} to `*` to return all payers' information under the organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePayerAccount(self, request, context):
        """Registers a vendor payer account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePayerAccount(self, request, context):
        """Deletes a vendor payer account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccounts(self, request, context):
        """Lists all vendor accounts.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccount(self, request, context):
        """Gets a vendor account. This API includes all of the account's metadata. See
        https://alphauslabs.github.io/blueapi/ for the list of supported attributes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccount(self, request, context):
        """Registers a vendor account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAccount(self, request, context):
        """Deletes a vendor account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCalculatorStatus(self, request, context):
        """WORK-IN-PROGRESS: Gets the vendor cost calculator's current status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCalculatorConfig(self, request, context):
        """WORK-IN-PROGRESS: Gets the vendor cost calculator's current configuration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportCurFiles(self, request, context):
        """Initiates an ondemand import of all registered CUR files. See
        [https://help.alphaus.cloud/en/articles/3612555-ripple-aws-things-you-need-to-prepare-before-starting]
        for more information.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CalculateCosts(self, request, context):
        """Triggers monthly calculations for costs and invoices at either organization or billing group level.
        For the AWS calculator, aggregation is done at daily and monthly level. Also, all occurrences of the
        character `|` (pipe) in the CUR descriptions and tag key/values are replaced with the `/` (forward-slash)
        character. This is due to the `|` character having a special designation in the data processing workflows.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCalculationsHistory(self, request, context):
        """Lists vendor costs calculations history and statuses.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadCosts(self, request, context):
        """Reads the usage-based cost details of an organization (Ripple) or billing group (Wave).
        At the moment, the supported {vendor} is 'aws'. If datetime range parameters are
        not set, month-to-date (current month) will be returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadAdjustments(self, request, context):
        """Reads the non-usage-based details of an organization (Ripple) or billing group (Wave).
        This API covers non-usage-based adjustments, such as Fees, Credits, Discounts, Tax,
        Upfront Fees, etc. At the moment, the supported {vendor} is 'aws'. If datetime
        range parameters are not set, month-to-date (current month) will be returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadTagCosts(self, request, context):
        """Reads the usage-based tag costs of a billing group. At the moment, the supported {vendor} is 
        'aws'. If datetime range parameters are not set, month-to-date (current month) will be returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadNonTagCosts(self, request, context):
        """Reads the usage-based non tag costs of a billing group. At the moment, the supported {vendor} is 
        'aws'. If datetime range parameters are not set, month-to-date (current month) will be returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetForecasts(self, request, context):
        """Fetches cost forecasts for the specified billing group.
        Includes historical cost (up to previous month) and forecasted cost (up to three months for now).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMonthlyCostForecast(self, request, context):
        """Fetches monthly accumulated costs vs forecasted cost vs budget for the id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMonthOnMonthCostForecast(self, request, context):
        """Fetches previous month cost vs current month forecast vs current accumulated cost per category for id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMonthToDateCostForecast(self, request, context):
        """Fetches current month daily forecast vs current accumulated daily cost for id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountBudget(self, request, context):
        """Fetches monthly budget for the account/acctgroup id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccountBudget(self, request, context):
        """Creates monthly budget for the account/acctgroup id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccountBudget(self, request, context):
        """Updates monthly budget for the account/acctgroup id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAccountBudget(self, request, context):
        """Removes monthly budget for the account/acctgroup id from database.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecommendations(self, request, context):
        """WORK-IN-PROGRESS: Get cost opmtimization recommendations for an organization (or MSP).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCostReduction(self, request, context):
        """WORK-IN-PROGRESS: Get cost reduction details for an organization (or MSP).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CostServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPayerAccounts': grpc.unary_stream_rpc_method_handler(
                    servicer.ListPayerAccounts,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.ListPayerAccountsRequest.FromString,
                    response_serializer=api_dot_account__pb2.Account.SerializeToString,
            ),
            'GetPayerAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPayerAccount,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetPayerAccountRequest.FromString,
                    response_serializer=api_dot_account__pb2.Account.SerializeToString,
            ),
            'GetPayerAccountImportHistory': grpc.unary_stream_rpc_method_handler(
                    servicer.GetPayerAccountImportHistory,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetPayerAccountImportHistoryRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.GetPayerAccountImportHistoryResponse.SerializeToString,
            ),
            'CreatePayerAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePayerAccount,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.CreatePayerAccountRequest.FromString,
                    response_serializer=api_dot_account__pb2.Account.SerializeToString,
            ),
            'DeletePayerAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePayerAccount,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.DeletePayerAccountRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListAccounts': grpc.unary_stream_rpc_method_handler(
                    servicer.ListAccounts,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.ListAccountsRequest.FromString,
                    response_serializer=api_dot_account__pb2.Account.SerializeToString,
            ),
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetAccountRequest.FromString,
                    response_serializer=api_dot_account__pb2.Account.SerializeToString,
            ),
            'CreateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccount,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.CreateAccountRequest.FromString,
                    response_serializer=api_dot_account__pb2.Account.SerializeToString,
            ),
            'DeleteAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAccount,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.DeleteAccountRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetCalculatorStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCalculatorStatus,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetCalculatorStatusRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.GetCalculatorStatusResponse.SerializeToString,
            ),
            'GetCalculatorConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCalculatorConfig,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetCalculatorConfigRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.GetCalculatorConfigResponse.SerializeToString,
            ),
            'ImportCurFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportCurFiles,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.ImportCurFilesRequest.FromString,
                    response_serializer=api_dot_operation__pb2.Operation.SerializeToString,
            ),
            'CalculateCosts': grpc.unary_unary_rpc_method_handler(
                    servicer.CalculateCosts,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.CalculateCostsRequest.FromString,
                    response_serializer=api_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListCalculationsHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCalculationsHistory,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.ListCalculationsHistoryRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.ListCalculationsHistoryResponse.SerializeToString,
            ),
            'ReadCosts': grpc.unary_stream_rpc_method_handler(
                    servicer.ReadCosts,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.ReadCostsRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.CostItem.SerializeToString,
            ),
            'ReadAdjustments': grpc.unary_stream_rpc_method_handler(
                    servicer.ReadAdjustments,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.ReadAdjustmentsRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.CostItem.SerializeToString,
            ),
            'ReadTagCosts': grpc.unary_stream_rpc_method_handler(
                    servicer.ReadTagCosts,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.ReadTagCostsRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.CostItem.SerializeToString,
            ),
            'ReadNonTagCosts': grpc.unary_stream_rpc_method_handler(
                    servicer.ReadNonTagCosts,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.ReadNonTagCostsRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.CostItem.SerializeToString,
            ),
            'GetForecasts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetForecasts,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetForecastsRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.GetForecastsResponse.SerializeToString,
            ),
            'GetMonthlyCostForecast': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMonthlyCostForecast,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetMonthlyCostForecastRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.GetMonthlyCostForecastResponse.SerializeToString,
            ),
            'GetMonthOnMonthCostForecast': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMonthOnMonthCostForecast,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetMonthOnMonthCostForecastRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.GetMonthOnMonthCostForecastResponse.SerializeToString,
            ),
            'GetMonthToDateCostForecast': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMonthToDateCostForecast,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetMonthToDateCostForecastRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.GetMonthToDateCostForecastResponse.SerializeToString,
            ),
            'GetAccountBudget': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountBudget,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetAccountBudgetRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.GetAccountBudgetResponse.SerializeToString,
            ),
            'CreateAccountBudget': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccountBudget,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.CreateAccountBudgetRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.CreateAccountBudgetResponse.SerializeToString,
            ),
            'UpdateAccountBudget': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccountBudget,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.UpdateAccountBudgetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteAccountBudget': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAccountBudget,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.DeleteAccountBudgetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetRecommendations': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecommendations,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetRecommendationsRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.GetRecommendationsResponse.SerializeToString,
            ),
            'GetCostReduction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCostReduction,
                    request_deserializer=cost_dot_v1_dot_cost__pb2.GetCostReductionRequest.FromString,
                    response_serializer=cost_dot_v1_dot_cost__pb2.GetCostReductionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'blueapi.cost.v1.Cost', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Cost(object):
    """Service for reading aggregated costs for your cloud costs and usages.
    """

    @staticmethod
    def ListPayerAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.cost.v1.Cost/ListPayerAccounts',
            cost_dot_v1_dot_cost__pb2.ListPayerAccountsRequest.SerializeToString,
            api_dot_account__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPayerAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/GetPayerAccount',
            cost_dot_v1_dot_cost__pb2.GetPayerAccountRequest.SerializeToString,
            api_dot_account__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPayerAccountImportHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.cost.v1.Cost/GetPayerAccountImportHistory',
            cost_dot_v1_dot_cost__pb2.GetPayerAccountImportHistoryRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.GetPayerAccountImportHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePayerAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/CreatePayerAccount',
            cost_dot_v1_dot_cost__pb2.CreatePayerAccountRequest.SerializeToString,
            api_dot_account__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePayerAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/DeletePayerAccount',
            cost_dot_v1_dot_cost__pb2.DeletePayerAccountRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.cost.v1.Cost/ListAccounts',
            cost_dot_v1_dot_cost__pb2.ListAccountsRequest.SerializeToString,
            api_dot_account__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/GetAccount',
            cost_dot_v1_dot_cost__pb2.GetAccountRequest.SerializeToString,
            api_dot_account__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/CreateAccount',
            cost_dot_v1_dot_cost__pb2.CreateAccountRequest.SerializeToString,
            api_dot_account__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/DeleteAccount',
            cost_dot_v1_dot_cost__pb2.DeleteAccountRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCalculatorStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/GetCalculatorStatus',
            cost_dot_v1_dot_cost__pb2.GetCalculatorStatusRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.GetCalculatorStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCalculatorConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/GetCalculatorConfig',
            cost_dot_v1_dot_cost__pb2.GetCalculatorConfigRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.GetCalculatorConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ImportCurFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/ImportCurFiles',
            cost_dot_v1_dot_cost__pb2.ImportCurFilesRequest.SerializeToString,
            api_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CalculateCosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/CalculateCosts',
            cost_dot_v1_dot_cost__pb2.CalculateCostsRequest.SerializeToString,
            api_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCalculationsHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/ListCalculationsHistory',
            cost_dot_v1_dot_cost__pb2.ListCalculationsHistoryRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.ListCalculationsHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadCosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.cost.v1.Cost/ReadCosts',
            cost_dot_v1_dot_cost__pb2.ReadCostsRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.CostItem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadAdjustments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.cost.v1.Cost/ReadAdjustments',
            cost_dot_v1_dot_cost__pb2.ReadAdjustmentsRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.CostItem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadTagCosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.cost.v1.Cost/ReadTagCosts',
            cost_dot_v1_dot_cost__pb2.ReadTagCostsRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.CostItem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadNonTagCosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.cost.v1.Cost/ReadNonTagCosts',
            cost_dot_v1_dot_cost__pb2.ReadNonTagCostsRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.CostItem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetForecasts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/GetForecasts',
            cost_dot_v1_dot_cost__pb2.GetForecastsRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.GetForecastsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMonthlyCostForecast(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/GetMonthlyCostForecast',
            cost_dot_v1_dot_cost__pb2.GetMonthlyCostForecastRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.GetMonthlyCostForecastResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMonthOnMonthCostForecast(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/GetMonthOnMonthCostForecast',
            cost_dot_v1_dot_cost__pb2.GetMonthOnMonthCostForecastRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.GetMonthOnMonthCostForecastResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMonthToDateCostForecast(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/GetMonthToDateCostForecast',
            cost_dot_v1_dot_cost__pb2.GetMonthToDateCostForecastRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.GetMonthToDateCostForecastResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccountBudget(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/GetAccountBudget',
            cost_dot_v1_dot_cost__pb2.GetAccountBudgetRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.GetAccountBudgetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAccountBudget(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/CreateAccountBudget',
            cost_dot_v1_dot_cost__pb2.CreateAccountBudgetRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.CreateAccountBudgetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccountBudget(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/UpdateAccountBudget',
            cost_dot_v1_dot_cost__pb2.UpdateAccountBudgetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAccountBudget(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/DeleteAccountBudget',
            cost_dot_v1_dot_cost__pb2.DeleteAccountBudgetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecommendations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/GetRecommendations',
            cost_dot_v1_dot_cost__pb2.GetRecommendationsRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.GetRecommendationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCostReduction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.cost.v1.Cost/GetCostReduction',
            cost_dot_v1_dot_cost__pb2.GetCostReductionRequest.SerializeToString,
            cost_dot_v1_dot_cost__pb2.GetCostReductionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/aws/calculator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/aws/calculator.proto',
  package='blueapi.api.aws',
  syntax='proto3',
  serialized_options=b'\n\035cloud.alphaus.blueapi.api.awsB\025ApiAwsCalculatorProtoZ*github.com/alphauslabs/blue-sdk-go/api/aws',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x61pi/aws/calculator.proto\x12\x0f\x62lueapi.api.aws\"$\n\x13\x41\x64justmentsTypeList\x12\r\n\x05types\x18\x01 \x03(\t\"j\n\x18\x45xcludedServiceFromUsage\x12\x19\n\x11managementAccount\x18\x01 \x01(\t\x12\x13\n\x0bproductCode\x18\x02 \x01(\t\x12\x1e\n\x16\x63onvertedToAdjustments\x18\x03 \x01(\x08\"\xa3\x01\n\x10\x43\x61lculatorConfig\x12\x41\n\x13\x61\x64justmentsTypeList\x18\x01 \x01(\x0b\x32$.blueapi.api.aws.AdjustmentsTypeList\x12L\n\x19\x65xcludedServicesFromUsage\x18\x02 \x03(\x0b\x32).blueapi.api.aws.ExcludedServiceFromUsageBb\n\x1d\x63loud.alphaus.blueapi.api.awsB\x15\x41piAwsCalculatorProtoZ*github.com/alphauslabs/blue-sdk-go/api/awsb\x06proto3'
)




_ADJUSTMENTSTYPELIST = _descriptor.Descriptor(
  name='AdjustmentsTypeList',
  full_name='blueapi.api.aws.AdjustmentsTypeList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='types', full_name='blueapi.api.aws.AdjustmentsTypeList.types', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=81,
)


_EXCLUDEDSERVICEFROMUSAGE = _descriptor.Descriptor(
  name='ExcludedServiceFromUsage',
  full_name='blueapi.api.aws.ExcludedServiceFromUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='managementAccount', full_name='blueapi.api.aws.ExcludedServiceFromUsage.managementAccount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCode', full_name='blueapi.api.aws.ExcludedServiceFromUsage.productCode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='convertedToAdjustments', full_name='blueapi.api.aws.ExcludedServiceFromUsage.convertedToAdjustments', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=189,
)


_CALCULATORCONFIG = _descriptor.Descriptor(
  name='CalculatorConfig',
  full_name='blueapi.api.aws.CalculatorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adjustmentsTypeList', full_name='blueapi.api.aws.CalculatorConfig.adjustmentsTypeList', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excludedServicesFromUsage', full_name='blueapi.api.aws.CalculatorConfig.excludedServicesFromUsage', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=355,
)

_CALCULATORCONFIG.fields_by_name['adjustmentsTypeList'].message_type = _ADJUSTMENTSTYPELIST
_CALCULATORCONFIG.fields_by_name['excludedServicesFromUsage'].message_type = _EXCLUDEDSERVICEFROMUSAGE
DESCRIPTOR.message_types_by_name['AdjustmentsTypeList'] = _ADJUSTMENTSTYPELIST
DESCRIPTOR.message_types_by_name['ExcludedServiceFromUsage'] = _EXCLUDEDSERVICEFROMUSAGE
DESCRIPTOR.message_types_by_name['CalculatorConfig'] = _CALCULATORCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdjustmentsTypeList = _reflection.GeneratedProtocolMessageType('AdjustmentsTypeList', (_message.Message,), {
  'DESCRIPTOR' : _ADJUSTMENTSTYPELIST,
  '__module__' : 'api.aws.calculator_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.AdjustmentsTypeList)
  })
_sym_db.RegisterMessage(AdjustmentsTypeList)

ExcludedServiceFromUsage = _reflection.GeneratedProtocolMessageType('ExcludedServiceFromUsage', (_message.Message,), {
  'DESCRIPTOR' : _EXCLUDEDSERVICEFROMUSAGE,
  '__module__' : 'api.aws.calculator_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.ExcludedServiceFromUsage)
  })
_sym_db.RegisterMessage(ExcludedServiceFromUsage)

CalculatorConfig = _reflection.GeneratedProtocolMessageType('CalculatorConfig', (_message.Message,), {
  'DESCRIPTOR' : _CALCULATORCONFIG,
  '__module__' : 'api.aws.calculator_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.CalculatorConfig)
  })
_sym_db.RegisterMessage(CalculatorConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from os import environ, getenv

from alphausblue.connection.session import Session

class TestSession:

    def test_all_values_empty_defaults_used(self):

        # First, set up the environment variables we want to use for testing
        environ["ALPHAUS_CLIENT_ID"] = "test-client-id"
        environ["ALPHAUS_CLIENT_SECRET"] = "test-client-secret"
        environ["ALPHAUS_USERNAME"] = "test-username"
        environ["ALPHAUS_PASSWORD"] = "test-password"
        environ["ALPHAUS_AUTH_URL"] = "https://test.test"

        # Next, create the session
        sess = Session()

        # Finally, verify the fields on the session
        assert sess.ClientId == "test-client-id"
        assert sess.ClientSecret == "test-client-secret"
        assert sess.GrantType == "password"
        assert sess.LoginUrl == "https://test.test"
        assert sess.Username == "test-username"
        assert sess.Password == "test-password"
        assert sess.Scope == "openid"
    
    def test_all_values_empty_auth_url_missing_ripple_used(self):
        
        # First, set up the environment variables we want to use for testing
        environ["ALPHAUS_CLIENT_ID"] = "test-client-id"
        environ["ALPHAUS_CLIENT_SECRET"] = "test-client-secret"
        environ["ALPHAUS_USERNAME"] = "test-username"
        environ["ALPHAUS_PASSWORD"] = "test-password"
        delete_if_exists("ALPHAUS_AUTH_URL")
        
        # Next, create the session
        sess = Session()

        # Finally, verify the fields on the session
        assert sess.ClientId == "test-client-id"
        assert sess.ClientSecret == "test-client-secret"
        assert sess.GrantType == "password"
        assert sess.LoginUrl == "https://login.alphaus.cloud/ripple/access_token"
        assert sess.Username == "test-username"
        assert sess.Password == "test-password"
        assert sess.Scope == "openid"
    
    def test_all_values_empty_alphaus_creds_missing_ripple_used(self):
        
        # First, set up the environment variables we want to use for testing
        delete_if_exists("ALPHAUS_CLIENT_ID")
        delete_if_exists("ALPHAUS_CLIENT_SECRET")
        environ["ALPHAUS_USERNAME"] = "test-username"
        environ["ALPHAUS_PASSWORD"] = "test-password"
        environ["ALPHAUS_RIPPLE_CLIENT_ID"] = "test-ripple-client-id"
        environ["ALPHAUS_RIPPLE_CLIENT_SECRET"] = "test-ripple-client-secret"
        environ["ALPHAUS_RIPPLE_USERNAME"] = "test-ripple-username"
        environ["ALPHAUS_RIPPLE_PASSWORD"] = "test-ripple-password"
        environ["ALPHAUS_AUTH_URL"] = "https://test.test"
        
        # Next, create the session
        sess = Session()

        # Finally, verify the fields on the session
        assert sess.ClientId == "test-ripple-client-id"
        assert sess.ClientSecret == "test-ripple-client-secret"
        assert sess.GrantType == "password"
        assert sess.LoginUrl == "https://login.alphaus.cloud/ripple/access_token"
        assert sess.Username == "test-ripple-username"
        assert sess.Password == "test-ripple-password"
        assert sess.Scope == "openid"

    def test_all_values_empty_alphaus_and_ripple_creds_missing_wave_used(self):
        
        # First, set up the environment variables we want to use for testing
        delete_if_exists("ALPHAUS_CLIENT_ID")
        delete_if_exists("ALPHAUS_CLIENT_SECRET")
        environ["ALPHAUS_USERNAME"] = "test-username"
        environ["ALPHAUS_PASSWORD"] = "test-password"
        environ["ALPHAUS_RIPPLE_USERNAME"] = "test-ripple-username"
        environ["ALPHAUS_RIPPLE_PASSWORD"] = "test-ripple-password"
        delete_if_exists("ALPHAUS_RIPPLE_CLIENT_ID")
        delete_if_exists("ALPHAUS_RIPPLE_CLIENT_SECRET")
        environ["ALPHAUS_WAVE_CLIENT_ID"] = "test-wave-client-id"
        environ["ALPHAUS_WAVE_CLIENT_SECRET"] = "test-wave-client-secret"
        environ["ALPHAUS_WAVE_USERNAME"] = "test-wave-username"
        environ["ALPHAUS_WAVE_PASSWORD"] = "test-wave-password"
        environ["ALPHAUS_AUTH_URL"] = "https://test.test"

        # Next, create the session
        sess = Session()

        # Finally, verify the fields on the session
        assert sess.ClientId == "test-wave-client-id"
        assert sess.ClientSecret == "test-wave-client-secret"
        assert sess.GrantType == "password"
        assert sess.LoginUrl == "https://login.alphaus.cloud/access_token"
        assert sess.Username == "test-wave-username"
        assert sess.Password == "test-wave-password"
        assert sess.Scope == "openid"
    
    def test_all_values_empty_username_and_password_missing_client_credentials(self):
        
        # First, set up the environment variables we want to use for testing
        environ["ALPHAUS_CLIENT_ID"] = "test-client-id"
        environ["ALPHAUS_CLIENT_SECRET"] = "test-client-secret"
        delete_if_exists("ALPHAUS_USERNAME")
        delete_if_exists("ALPHAUS_PASSWORD")
        delete_if_exists("ALPHAUS_AUTH_URL")
        
        # Next, create the session
        sess = Session()

        # Finally, verify the fields on the session
        assert sess.ClientId == "test-client-id"
        assert sess.ClientSecret == "test-client-secret"
        assert sess.GrantType == "client_credentials"
        assert sess.LoginUrl == "https://login.alphaus.cloud/ripple/access_token"
        assert sess.Username == None
        assert sess.Password == None
        assert sess.Scope == "openid"
    
    def test_all_values_provided_populated(self):

        # First, create the session with values provided
        sess = Session(
            client_id = "test-func-client-id",
            client_secret = "test-func-client-secret",
            grant_type = "grant",
            scope = "jwt",
            username = "test-func-username",
            password = "test-func-password",
            login_url = "https://test.func.test")
            
        # Finally, verify the fields on the session
        assert sess.ClientId == "test-func-client-id"
        assert sess.ClientSecret == "test-func-client-secret"
        assert sess.GrantType == "grant"
        assert sess.LoginUrl == "https://test.func.test"
        assert sess.Username == "test-func-username"
        assert sess.Password == "test-func-password"
        assert sess.Scope == "jwt"
    
    def test_access_token_works(self):

        # First, get the client ID and secret from the Ripple tester environment variables
        # If the variables could not be found then print a message and exit
        client_id = getenv("RIPPLE_TESTER_CLIENT_ID_PROD")
        client_secret = getenv("RIPPLE_TESTER_CLIENT_SECRET_PROD")
        if not (client_id and client_secret):
            print("Client ID and secret not found, exiting")
            return

        # Next, create the session from the client ID and secret
        sess = Session(
            client_id = client_id,
            client_secret = client_secret)
        
        # Finally, attempt to get an access token; this should not fail
        token = sess.access_token()
        print("Token {0}: ".format(token))

def delete_if_exists(key):
    if key in environ:
        del environ[key]


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/admin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from alphausblue.api import accountgroup_pb2 as api_dot_accountgroup__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='admin/v1/admin.proto',
  package='blueapi.admin.v1',
  syntax='proto3',
  serialized_options=b'\n\027cloud.alphaus.api.adminB\nAdminProtoZ$github.com/alphauslabs/blueapi/admin',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14\x61\x64min/v1/admin.proto\x12\x10\x62lueapi.admin.v1\x1a\x16\x61pi/accountgroup.proto\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x1a\n\x18ListAccountGroupsRequest\"M\n\x19ListAccountGroupsResponse\x12\x30\n\raccountGroups\x18\x01 \x03(\x0b\x32\x19.blueapi.api.AccountGroup\"$\n\x16GetAccountGroupRequest\x12\n\n\x02id\x18\x01 \x01(\t\"G\n\x17GetAccountGroupResponse\x12,\n\tacctGroup\x18\x01 \x01(\x0b\x32\x19.blueapi.api.AccountGroup2\xb6\x03\n\x05\x41\x64min\x12\x8c\x01\n\x11ListAccountGroups\x12*.blueapi.admin.v1.ListAccountGroupsRequest\x1a+.blueapi.admin.v1.ListAccountGroupsResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/admin/v1/acctgroups0\x01\x12\x89\x01\n\x0fGetAccountGroup\x12(.blueapi.admin.v1.GetAccountGroupRequest\x1a).blueapi.admin.v1.GetAccountGroupResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/admin/v1/acctgroups/{id}\x1a\x91\x01\x92\x41\x8d\x01\x12<(BETA) Admin API. Base URL: https://api.alphaus.cloud/m/blue\x1aM\n\x12Service definition\x12\x37https://github.com/alphauslabs/blueapi/tree/main/admin/BK\n\x17\x63loud.alphaus.api.adminB\nAdminProtoZ$github.com/alphauslabs/blueapi/adminb\x06proto3'
  ,
  dependencies=[api_dot_accountgroup__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__openapiv2_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_LISTACCOUNTGROUPSREQUEST = _descriptor.Descriptor(
  name='ListAccountGroupsRequest',
  full_name='blueapi.admin.v1.ListAccountGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=170,
)


_LISTACCOUNTGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListAccountGroupsResponse',
  full_name='blueapi.admin.v1.ListAccountGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountGroups', full_name='blueapi.admin.v1.ListAccountGroupsResponse.accountGroups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=249,
)


_GETACCOUNTGROUPREQUEST = _descriptor.Descriptor(
  name='GetAccountGroupRequest',
  full_name='blueapi.admin.v1.GetAccountGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.admin.v1.GetAccountGroupRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=287,
)


_GETACCOUNTGROUPRESPONSE = _descriptor.Descriptor(
  name='GetAccountGroupResponse',
  full_name='blueapi.admin.v1.GetAccountGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='acctGroup', full_name='blueapi.admin.v1.GetAccountGroupResponse.acctGroup', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=360,
)

_LISTACCOUNTGROUPSRESPONSE.fields_by_name['accountGroups'].message_type = api_dot_accountgroup__pb2._ACCOUNTGROUP
_GETACCOUNTGROUPRESPONSE.fields_by_name['acctGroup'].message_type = api_dot_accountgroup__pb2._ACCOUNTGROUP
DESCRIPTOR.message_types_by_name['ListAccountGroupsRequest'] = _LISTACCOUNTGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListAccountGroupsResponse'] = _LISTACCOUNTGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['GetAccountGroupRequest'] = _GETACCOUNTGROUPREQUEST
DESCRIPTOR.message_types_by_name['GetAccountGroupResponse'] = _GETACCOUNTGROUPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListAccountGroupsRequest = _reflection.GeneratedProtocolMessageType('ListAccountGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTGROUPSREQUEST,
  '__module__' : 'admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.admin.v1.ListAccountGroupsRequest)
  })
_sym_db.RegisterMessage(ListAccountGroupsRequest)

ListAccountGroupsResponse = _reflection.GeneratedProtocolMessageType('ListAccountGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTGROUPSRESPONSE,
  '__module__' : 'admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.admin.v1.ListAccountGroupsResponse)
  })
_sym_db.RegisterMessage(ListAccountGroupsResponse)

GetAccountGroupRequest = _reflection.GeneratedProtocolMessageType('GetAccountGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTGROUPREQUEST,
  '__module__' : 'admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.admin.v1.GetAccountGroupRequest)
  })
_sym_db.RegisterMessage(GetAccountGroupRequest)

GetAccountGroupResponse = _reflection.GeneratedProtocolMessageType('GetAccountGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTGROUPRESPONSE,
  '__module__' : 'admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.admin.v1.GetAccountGroupResponse)
  })
_sym_db.RegisterMessage(GetAccountGroupResponse)


DESCRIPTOR._options = None

_ADMIN = _descriptor.ServiceDescriptor(
  name='Admin',
  full_name='blueapi.admin.v1.Admin',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\222A\215\001\022<(BETA) Admin API. Base URL: https://api.alphaus.cloud/m/blue\032M\n\022Service definition\0227https://github.com/alphauslabs/blueapi/tree/main/admin/',
  create_key=_descriptor._internal_create_key,
  serialized_start=363,
  serialized_end=801,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListAccountGroups',
    full_name='blueapi.admin.v1.Admin.ListAccountGroups',
    index=0,
    containing_service=None,
    input_type=_LISTACCOUNTGROUPSREQUEST,
    output_type=_LISTACCOUNTGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\022\024/admin/v1/acctgroups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountGroup',
    full_name='blueapi.admin.v1.Admin.GetAccountGroup',
    index=1,
    containing_service=None,
    input_type=_GETACCOUNTGROUPREQUEST,
    output_type=_GETACCOUNTGROUPRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/admin/v1/acctgroups/{id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADMIN)

DESCRIPTOR.services_by_name['Admin'] = _ADMIN

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/operation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/operation.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\021ApiOperationProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13\x61pi/operation.proto\x12\x0b\x62lueapi.api\x1a\x17google/rpc/status.proto\x1a\x19google/protobuf/any.proto\"\xa8\x01\n\tOperation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x08metadata\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04\x64one\x18\x03 \x01(\x08\x12#\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x12(\n\x08response\x18\x05 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06result\"a\n\x1cOperationImportCurMetadataV1\x12\r\n\x05month\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63\x63ounts\x18\x02 \x03(\t\x12\x0f\n\x07\x63reated\x18\x03 \x01(\t\x12\x0f\n\x07updated\x18\x04 \x01(\t\"\x88\x01\n$OperationAwsCalculateCostsMetadataV1\x12\r\n\x05orgId\x18\x01 \x01(\t\x12\r\n\x05month\x18\x02 \x01(\t\x12\x10\n\x08groupIds\x18\x03 \x03(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0f\n\x07\x63reated\x18\x05 \x01(\t\x12\x0f\n\x07updated\x18\x06 \x01(\tBV\n\x19\x63loud.alphaus.blueapi.apiB\x11\x41piOperationProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
  ,
  dependencies=[google_dot_rpc_dot_status__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_OPERATION = _descriptor.Descriptor(
  name='Operation',
  full_name='blueapi.api.Operation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.api.Operation.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='blueapi.api.Operation.metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='done', full_name='blueapi.api.Operation.done', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='blueapi.api.Operation.error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='blueapi.api.Operation.response', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='blueapi.api.Operation.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=89,
  serialized_end=257,
)


_OPERATIONIMPORTCURMETADATAV1 = _descriptor.Descriptor(
  name='OperationImportCurMetadataV1',
  full_name='blueapi.api.OperationImportCurMetadataV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='month', full_name='blueapi.api.OperationImportCurMetadataV1.month', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accounts', full_name='blueapi.api.OperationImportCurMetadataV1.accounts', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='blueapi.api.OperationImportCurMetadataV1.created', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='blueapi.api.OperationImportCurMetadataV1.updated', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=356,
)


_OPERATIONAWSCALCULATECOSTSMETADATAV1 = _descriptor.Descriptor(
  name='OperationAwsCalculateCostsMetadataV1',
  full_name='blueapi.api.OperationAwsCalculateCostsMetadataV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgId', full_name='blueapi.api.OperationAwsCalculateCostsMetadataV1.orgId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='blueapi.api.OperationAwsCalculateCostsMetadataV1.month', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupIds', full_name='blueapi.api.OperationAwsCalculateCostsMetadataV1.groupIds', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='blueapi.api.OperationAwsCalculateCostsMetadataV1.status', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='blueapi.api.OperationAwsCalculateCostsMetadataV1.created', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='blueapi.api.OperationAwsCalculateCostsMetadataV1.updated', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=359,
  serialized_end=495,
)

_OPERATION.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_OPERATION.fields_by_name['error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_OPERATION.fields_by_name['response'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_OPERATION.oneofs_by_name['result'].fields.append(
  _OPERATION.fields_by_name['error'])
_OPERATION.fields_by_name['error'].containing_oneof = _OPERATION.oneofs_by_name['result']
_OPERATION.oneofs_by_name['result'].fields.append(
  _OPERATION.fields_by_name['response'])
_OPERATION.fields_by_name['response'].containing_oneof = _OPERATION.oneofs_by_name['result']
DESCRIPTOR.message_types_by_name['Operation'] = _OPERATION
DESCRIPTOR.message_types_by_name['OperationImportCurMetadataV1'] = _OPERATIONIMPORTCURMETADATAV1
DESCRIPTOR.message_types_by_name['OperationAwsCalculateCostsMetadataV1'] = _OPERATIONAWSCALCULATECOSTSMETADATAV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Operation = _reflection.GeneratedProtocolMessageType('Operation', (_message.Message,), {
  'DESCRIPTOR' : _OPERATION,
  '__module__' : 'api.operation_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.Operation)
  })
_sym_db.RegisterMessage(Operation)

OperationImportCurMetadataV1 = _reflection.GeneratedProtocolMessageType('OperationImportCurMetadataV1', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONIMPORTCURMETADATAV1,
  '__module__' : 'api.operation_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OperationImportCurMetadataV1)
  })
_sym_db.RegisterMessage(OperationImportCurMetadataV1)

OperationAwsCalculateCostsMetadataV1 = _reflection.GeneratedProtocolMessageType('OperationAwsCalculateCostsMetadataV1', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONAWSCALCULATECOSTSMETADATAV1,
  '__module__' : 'api.operation_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OperationAwsCalculateCostsMetadataV1)
  })
_sym_db.RegisterMessage(OperationAwsCalculateCostsMetadataV1)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from alphausblue.billing.v1 import billing_pb2 as billing_dot_v1_dot_billing__pb2


class BillingStub(object):
    """Billing service definition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListBillingGroups = channel.unary_stream(
                '/blueapi.billing.v1.Billing/ListBillingGroups',
                request_serializer=billing_dot_v1_dot_billing__pb2.ListBillingGroupsRequest.SerializeToString,
                response_deserializer=billing_dot_v1_dot_billing__pb2.BillingGroup.FromString,
                )
        self.CreateBillingGroup = channel.unary_unary(
                '/blueapi.billing.v1.Billing/CreateBillingGroup',
                request_serializer=billing_dot_v1_dot_billing__pb2.CreateBillingGroupRequest.SerializeToString,
                response_deserializer=billing_dot_v1_dot_billing__pb2.BillingGroup.FromString,
                )
        self.GetBillingGroup = channel.unary_unary(
                '/blueapi.billing.v1.Billing/GetBillingGroup',
                request_serializer=billing_dot_v1_dot_billing__pb2.GetBillingGroupRequest.SerializeToString,
                response_deserializer=billing_dot_v1_dot_billing__pb2.GetBillingGroupResponse.FromString,
                )


class BillingServicer(object):
    """Billing service definition.
    """

    def ListBillingGroups(self, request, context):
        """Lists all billing groups.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBillingGroup(self, request, context):
        """Registers a billing group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBillingGroup(self, request, context):
        """Gets a billing group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BillingServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListBillingGroups': grpc.unary_stream_rpc_method_handler(
                    servicer.ListBillingGroups,
                    request_deserializer=billing_dot_v1_dot_billing__pb2.ListBillingGroupsRequest.FromString,
                    response_serializer=billing_dot_v1_dot_billing__pb2.BillingGroup.SerializeToString,
            ),
            'CreateBillingGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBillingGroup,
                    request_deserializer=billing_dot_v1_dot_billing__pb2.CreateBillingGroupRequest.FromString,
                    response_serializer=billing_dot_v1_dot_billing__pb2.BillingGroup.SerializeToString,
            ),
            'GetBillingGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBillingGroup,
                    request_deserializer=billing_dot_v1_dot_billing__pb2.GetBillingGroupRequest.FromString,
                    response_serializer=billing_dot_v1_dot_billing__pb2.GetBillingGroupResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'blueapi.billing.v1.Billing', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Billing(object):
    """Billing service definition.
    """

    @staticmethod
    def ListBillingGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.billing.v1.Billing/ListBillingGroups',
            billing_dot_v1_dot_billing__pb2.ListBillingGroupsRequest.SerializeToString,
            billing_dot_v1_dot_billing__pb2.BillingGroup.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateBillingGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.billing.v1.Billing/CreateBillingGroup',
            billing_dot_v1_dot_billing__pb2.CreateBillingGroupRequest.SerializeToString,
            billing_dot_v1_dot_billing__pb2.BillingGroup.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBillingGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.billing.v1.Billing/GetBillingGroup',
            billing_dot_v1_dot_billing__pb2.GetBillingGroupRequest.SerializeToString,
            billing_dot_v1_dot_billing__pb2.GetBillingGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/budget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/budget.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\016ApiBudgetProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x61pi/budget.proto\x12\x0b\x62lueapi.api\"[\n\x06\x42udget\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nfiscalYear\x18\x02 \x01(\t\x12\x31\n\rmonthlyBudget\x18\x03 \x03(\x0b\x32\x1a.blueapi.api.MonthlyBudget\"2\n\rMonthlyBudget\x12\x11\n\tyearMonth\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x42S\n\x19\x63loud.alphaus.blueapi.apiB\x0e\x41piBudgetProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
)




_BUDGET = _descriptor.Descriptor(
  name='Budget',
  full_name='blueapi.api.Budget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.Budget.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fiscalYear', full_name='blueapi.api.Budget.fiscalYear', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monthlyBudget', full_name='blueapi.api.Budget.monthlyBudget', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=124,
)


_MONTHLYBUDGET = _descriptor.Descriptor(
  name='MonthlyBudget',
  full_name='blueapi.api.MonthlyBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='yearMonth', full_name='blueapi.api.MonthlyBudget.yearMonth', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='blueapi.api.MonthlyBudget.amount', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=176,
)

_BUDGET.fields_by_name['monthlyBudget'].message_type = _MONTHLYBUDGET
DESCRIPTOR.message_types_by_name['Budget'] = _BUDGET
DESCRIPTOR.message_types_by_name['MonthlyBudget'] = _MONTHLYBUDGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Budget = _reflection.GeneratedProtocolMessageType('Budget', (_message.Message,), {
  'DESCRIPTOR' : _BUDGET,
  '__module__' : 'api.budget_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.Budget)
  })
_sym_db.RegisterMessage(Budget)

MonthlyBudget = _reflection.GeneratedProtocolMessageType('MonthlyBudget', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYBUDGET,
  '__module__' : 'api.budget_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.MonthlyBudget)
  })
_sym_db.RegisterMessage(MonthlyBudget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from alphausblue.api import keyvalue_pb2 as api_dot_keyvalue__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/account.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\017ApiAccountProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x61pi/account.proto\x12\x0b\x62lueapi.api\x1a\x12\x61pi/keyvalue.proto\"L\n\x07\x41\x63\x63ount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\'\n\x08metadata\x18\x03 \x03(\x0b\x32\x15.blueapi.api.KeyValueBT\n\x19\x63loud.alphaus.blueapi.apiB\x0f\x41piAccountProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
  ,
  dependencies=[api_dot_keyvalue__pb2.DESCRIPTOR,])




_ACCOUNT = _descriptor.Descriptor(
  name='Account',
  full_name='blueapi.api.Account',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.Account.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.api.Account.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='blueapi.api.Account.metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=130,
)

_ACCOUNT.fields_by_name['metadata'].message_type = api_dot_keyvalue__pb2._KEYVALUE
DESCRIPTOR.message_types_by_name['Account'] = _ACCOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Account = _reflection.GeneratedProtocolMessageType('Account', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNT,
  '__module__' : 'api.account_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.Account)
  })
_sym_db.RegisterMessage(Account)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/forecast.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/forecast.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\020ApiForecastProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12\x61pi/forecast.proto\x12\x0b\x62lueapi.api\"\xc8\x01\n\x0c\x46orecastData\x12\x11\n\taccountId\x18\x01 \x01(\t\x12\x17\n\x0fproductCategory\x18\x02 \x01(\t\x12\x13\n\x0bproductCode\x18\x03 \x01(\t\x12\x11\n\tfrequency\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x05 \x01(\t\x12\x16\n\x0ehistoricalCost\x18\x06 \x01(\x01\x12\x16\n\x0e\x66orecastedCost\x18\x07 \x01(\x01\x12\x12\n\nupperBound\x18\x08 \x01(\x01\x12\x12\n\nlowerBound\x18\t \x01(\x01\"P\n\x14\x41\x63\x63ountGroupForecast\x12\x0f\n\x07groupId\x18\x01 \x01(\t\x12\'\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x19.blueapi.api.ForecastData\"R\n\x14\x42illingGroupForecast\x12\x11\n\tcompanyId\x18\x01 \x01(\t\x12\'\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x19.blueapi.api.ForecastData\"M\n\x0bOrgForecast\x12\r\n\x05orgId\x18\x01 \x01(\t\x12/\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32!.blueapi.api.BillingGroupForecast\"\xa7\x01\n\x17MonthToDateForecastData\x12\x11\n\taccountId\x18\x01 \x01(\t\x12\x17\n\x0fproductCategory\x18\x02 \x01(\t\x12\x13\n\x0bproductCode\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\t\x12\x17\n\x0f\x61\x63\x63umulatedCost\x18\x05 \x01(\x01\x12\x14\n\x0c\x66orecastCost\x18\x06 \x01(\x01\x12\x0e\n\x06\x62udget\x18\x07 \x01(\x01\"h\n\x1f\x42illingGroupMonthToDateForecast\x12\x11\n\tcompanyId\x18\x01 \x01(\t\x12\x32\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32$.blueapi.api.MonthToDateForecastData\"c\n\x16OrgMonthToDateForecast\x12\r\n\x05orgId\x18\x01 \x01(\t\x12:\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32,.blueapi.api.BillingGroupMonthToDateForecast\"\x85\x01\n\x13MonthlyCostForecast\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x12\n\ncostActual\x18\x02 \x01(\x01\x12\x14\n\x0c\x63ostForecast\x18\x03 \x01(\x01\x12\x0e\n\x06\x62udget\x18\x04 \x01(\x01\x12\x12\n\nupperBound\x18\x05 \x01(\x01\x12\x12\n\nlowerBound\x18\x06 \x01(\x01\"i\n\x18MonthOnMonthCostForecast\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x13\n\x0b\x63ostCurrent\x18\x02 \x01(\x01\x12\x10\n\x08\x63ostPrev\x18\x03 \x01(\x01\x12\x14\n\x0c\x63ostForecast\x18\x04 \x01(\x01\"\x90\x01\n\x17MonthToDateCostForecast\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x10\n\x08\x63ostPrev\x18\x02 \x01(\x01\x12\x17\n\x0f\x63ostAccumulated\x18\x03 \x01(\x01\x12\x14\n\x0c\x63ostForecast\x18\x04 \x01(\x01\x12\x12\n\nupperBound\x18\x05 \x01(\x01\x12\x12\n\nlowerBound\x18\x06 \x01(\x01\x42U\n\x19\x63loud.alphaus.blueapi.apiB\x10\x41piForecastProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
)




_FORECASTDATA = _descriptor.Descriptor(
  name='ForecastData',
  full_name='blueapi.api.ForecastData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountId', full_name='blueapi.api.ForecastData.accountId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCategory', full_name='blueapi.api.ForecastData.productCategory', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCode', full_name='blueapi.api.ForecastData.productCode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='blueapi.api.ForecastData.frequency', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.ForecastData.date', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='historicalCost', full_name='blueapi.api.ForecastData.historicalCost', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forecastedCost', full_name='blueapi.api.ForecastData.forecastedCost', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upperBound', full_name='blueapi.api.ForecastData.upperBound', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowerBound', full_name='blueapi.api.ForecastData.lowerBound', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=236,
)


_ACCOUNTGROUPFORECAST = _descriptor.Descriptor(
  name='AccountGroupForecast',
  full_name='blueapi.api.AccountGroupForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupId', full_name='blueapi.api.AccountGroupForecast.groupId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.api.AccountGroupForecast.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=318,
)


_BILLINGGROUPFORECAST = _descriptor.Descriptor(
  name='BillingGroupForecast',
  full_name='blueapi.api.BillingGroupForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='companyId', full_name='blueapi.api.BillingGroupForecast.companyId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.api.BillingGroupForecast.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=402,
)


_ORGFORECAST = _descriptor.Descriptor(
  name='OrgForecast',
  full_name='blueapi.api.OrgForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgId', full_name='blueapi.api.OrgForecast.orgId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.api.OrgForecast.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=481,
)


_MONTHTODATEFORECASTDATA = _descriptor.Descriptor(
  name='MonthToDateForecastData',
  full_name='blueapi.api.MonthToDateForecastData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountId', full_name='blueapi.api.MonthToDateForecastData.accountId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCategory', full_name='blueapi.api.MonthToDateForecastData.productCategory', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCode', full_name='blueapi.api.MonthToDateForecastData.productCode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.MonthToDateForecastData.date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accumulatedCost', full_name='blueapi.api.MonthToDateForecastData.accumulatedCost', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forecastCost', full_name='blueapi.api.MonthToDateForecastData.forecastCost', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='budget', full_name='blueapi.api.MonthToDateForecastData.budget', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=651,
)


_BILLINGGROUPMONTHTODATEFORECAST = _descriptor.Descriptor(
  name='BillingGroupMonthToDateForecast',
  full_name='blueapi.api.BillingGroupMonthToDateForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='companyId', full_name='blueapi.api.BillingGroupMonthToDateForecast.companyId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.api.BillingGroupMonthToDateForecast.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=757,
)


_ORGMONTHTODATEFORECAST = _descriptor.Descriptor(
  name='OrgMonthToDateForecast',
  full_name='blueapi.api.OrgMonthToDateForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgId', full_name='blueapi.api.OrgMonthToDateForecast.orgId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.api.OrgMonthToDateForecast.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=858,
)


_MONTHLYCOSTFORECAST = _descriptor.Descriptor(
  name='MonthlyCostForecast',
  full_name='blueapi.api.MonthlyCostForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.MonthlyCostForecast.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costActual', full_name='blueapi.api.MonthlyCostForecast.costActual', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costForecast', full_name='blueapi.api.MonthlyCostForecast.costForecast', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='budget', full_name='blueapi.api.MonthlyCostForecast.budget', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upperBound', full_name='blueapi.api.MonthlyCostForecast.upperBound', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowerBound', full_name='blueapi.api.MonthlyCostForecast.lowerBound', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=994,
)


_MONTHONMONTHCOSTFORECAST = _descriptor.Descriptor(
  name='MonthOnMonthCostForecast',
  full_name='blueapi.api.MonthOnMonthCostForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='blueapi.api.MonthOnMonthCostForecast.category', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costCurrent', full_name='blueapi.api.MonthOnMonthCostForecast.costCurrent', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costPrev', full_name='blueapi.api.MonthOnMonthCostForecast.costPrev', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costForecast', full_name='blueapi.api.MonthOnMonthCostForecast.costForecast', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=996,
  serialized_end=1101,
)


_MONTHTODATECOSTFORECAST = _descriptor.Descriptor(
  name='MonthToDateCostForecast',
  full_name='blueapi.api.MonthToDateCostForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.MonthToDateCostForecast.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costPrev', full_name='blueapi.api.MonthToDateCostForecast.costPrev', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costAccumulated', full_name='blueapi.api.MonthToDateCostForecast.costAccumulated', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costForecast', full_name='blueapi.api.MonthToDateCostForecast.costForecast', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upperBound', full_name='blueapi.api.MonthToDateCostForecast.upperBound', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowerBound', full_name='blueapi.api.MonthToDateCostForecast.lowerBound', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1104,
  serialized_end=1248,
)

_ACCOUNTGROUPFORECAST.fields_by_name['data'].message_type = _FORECASTDATA
_BILLINGGROUPFORECAST.fields_by_name['data'].message_type = _FORECASTDATA
_ORGFORECAST.fields_by_name['data'].message_type = _BILLINGGROUPFORECAST
_BILLINGGROUPMONTHTODATEFORECAST.fields_by_name['data'].message_type = _MONTHTODATEFORECASTDATA
_ORGMONTHTODATEFORECAST.fields_by_name['data'].message_type = _BILLINGGROUPMONTHTODATEFORECAST
DESCRIPTOR.message_types_by_name['ForecastData'] = _FORECASTDATA
DESCRIPTOR.message_types_by_name['AccountGroupForecast'] = _ACCOUNTGROUPFORECAST
DESCRIPTOR.message_types_by_name['BillingGroupForecast'] = _BILLINGGROUPFORECAST
DESCRIPTOR.message_types_by_name['OrgForecast'] = _ORGFORECAST
DESCRIPTOR.message_types_by_name['MonthToDateForecastData'] = _MONTHTODATEFORECASTDATA
DESCRIPTOR.message_types_by_name['BillingGroupMonthToDateForecast'] = _BILLINGGROUPMONTHTODATEFORECAST
DESCRIPTOR.message_types_by_name['OrgMonthToDateForecast'] = _ORGMONTHTODATEFORECAST
DESCRIPTOR.message_types_by_name['MonthlyCostForecast'] = _MONTHLYCOSTFORECAST
DESCRIPTOR.message_types_by_name['MonthOnMonthCostForecast'] = _MONTHONMONTHCOSTFORECAST
DESCRIPTOR.message_types_by_name['MonthToDateCostForecast'] = _MONTHTODATECOSTFORECAST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ForecastData = _reflection.GeneratedProtocolMessageType('ForecastData', (_message.Message,), {
  'DESCRIPTOR' : _FORECASTDATA,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.ForecastData)
  })
_sym_db.RegisterMessage(ForecastData)

AccountGroupForecast = _reflection.GeneratedProtocolMessageType('AccountGroupForecast', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.AccountGroupForecast)
  })
_sym_db.RegisterMessage(AccountGroupForecast)

BillingGroupForecast = _reflection.GeneratedProtocolMessageType('BillingGroupForecast', (_message.Message,), {
  'DESCRIPTOR' : _BILLINGGROUPFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.BillingGroupForecast)
  })
_sym_db.RegisterMessage(BillingGroupForecast)

OrgForecast = _reflection.GeneratedProtocolMessageType('OrgForecast', (_message.Message,), {
  'DESCRIPTOR' : _ORGFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OrgForecast)
  })
_sym_db.RegisterMessage(OrgForecast)

MonthToDateForecastData = _reflection.GeneratedProtocolMessageType('MonthToDateForecastData', (_message.Message,), {
  'DESCRIPTOR' : _MONTHTODATEFORECASTDATA,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.MonthToDateForecastData)
  })
_sym_db.RegisterMessage(MonthToDateForecastData)

BillingGroupMonthToDateForecast = _reflection.GeneratedProtocolMessageType('BillingGroupMonthToDateForecast', (_message.Message,), {
  'DESCRIPTOR' : _BILLINGGROUPMONTHTODATEFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.BillingGroupMonthToDateForecast)
  })
_sym_db.RegisterMessage(BillingGroupMonthToDateForecast)

OrgMonthToDateForecast = _reflection.GeneratedProtocolMessageType('OrgMonthToDateForecast', (_message.Message,), {
  'DESCRIPTOR' : _ORGMONTHTODATEFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OrgMonthToDateForecast)
  })
_sym_db.RegisterMessage(OrgMonthToDateForecast)

MonthlyCostForecast = _reflection.GeneratedProtocolMessageType('MonthlyCostForecast', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYCOSTFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.MonthlyCostForecast)
  })
_sym_db.RegisterMessage(MonthlyCostForecast)

MonthOnMonthCostForecast = _reflection.GeneratedProtocolMessageType('MonthOnMonthCostForecast', (_message.Message,), {
  'DESCRIPTOR' : _MONTHONMONTHCOSTFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.MonthOnMonthCostForecast)
  })
_sym_db.RegisterMessage(MonthOnMonthCostForecast)

MonthToDateCostForecast = _reflection.GeneratedProtocolMessageType('MonthToDateCostForecast', (_message.Message,), {
  'DESCRIPTOR' : _MONTHTODATECOSTFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.MonthToDateCostForecast)
  })
_sym_db.RegisterMessage(MonthToDateCostForecast)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
